An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.

Structs

Generated client accounts for EntryClose.

Generated client accounts for Initialize.

Generated client accounts for NodeRegister.

Generated client accounts for NodeStake.

Generated client accounts for RotatorTurn.

Generated client accounts for SnapshotCapture.

Generated client accounts for SnapshotClose.

Generated client accounts for SnapshotRotate.

Generated client accounts for SnapshotStart.