Struct clockwork_network::accounts::NodeStake
source · [−]pub struct NodeStake {
pub config: Pubkey,
pub node: Pubkey,
pub node_stake: Pubkey,
pub mint: Pubkey,
pub signer: Pubkey,
pub token_program: Pubkey,
pub tokens: Pubkey,
pub worker: Pubkey,
}Expand description
Generated client accounts for NodeStake.
Fields
config: Pubkeynode: Pubkeynode_stake: Pubkeymint: Pubkeysigner: Pubkeytoken_program: Pubkeytokens: Pubkeyworker: PubkeyTrait Implementations
sourceimpl BorshSerialize for NodeStake where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for NodeStake where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for NodeStake
impl ToAccountMetas for NodeStake
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more