Struct clockwork_network::accounts::RotatorTurn
source · [−]pub struct RotatorTurn {
pub config: Pubkey,
pub entry: Pubkey,
pub pool: Pubkey,
pub pool_config: Pubkey,
pub pool_program: Pubkey,
pub rotator: Pubkey,
pub signer: Pubkey,
pub snapshot: Pubkey,
pub worker: Pubkey,
}Expand description
Generated client accounts for RotatorTurn.
Fields
config: Pubkeyentry: Pubkeypool: Pubkeypool_config: Pubkeypool_program: Pubkeyrotator: Pubkeysigner: Pubkeysnapshot: Pubkeyworker: PubkeyTrait Implementations
sourceimpl BorshSerialize for RotatorTurn where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
impl BorshSerialize for RotatorTurn where
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for RotatorTurn
impl ToAccountMetas for RotatorTurn
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client. Read more