pub struct SnapshotResume {
pub admin: Pubkey,
pub authority: Pubkey,
pub clockwork_program: Pubkey,
pub config: Pubkey,
pub snapshot_queue: Pubkey,
}Expand description
Generated client accounts for SnapshotResume.
Fields
admin: Pubkeyclockwork_program: Pubkeyconfig: Pubkeysnapshot_queue: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SnapshotResumewhere
Pubkey: BorshSerialize,
impl BorshSerialize for SnapshotResumewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SnapshotResume
impl ToAccountMetas for SnapshotResume
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SnapshotResume
impl RefUnwindSafe for SnapshotResume
impl Send for SnapshotResume
impl Sync for SnapshotResume
impl Unpin for SnapshotResume
impl UnwindSafe for SnapshotResume